@@ -8,28 +8,19 @@
 from __future__ import absolute_import
 from __future__ import division
 
-from .animation import *
-from .formatter import *
-from .shell import *
-from .irc import *
-from .nuts import *
-from .tinymux import *
+
+#pylint: disable=W0401
+from shellpic.animation import *
+from shellpic.formatter import *
+from shellpic.shell import *
+from shellpic.irc import *
+from shellpic.nuts import *
+from shellpic.tinymux import *
 
 import PIL
 from collections import Sequence
 
-# there is a fix set for Pillow-2.6 that fixes a bug in the dispose
-# handling for animated GIF. We monkey patch it here until that
-# version is released.
-from PIL import GifImagePlugin
-from .GifImagePlugin import GifImageFile, _accept, _save
-
-PIL.Image.register_open(GifImageFile.format, GifImageFile, _accept)
-PIL.Image.register_save(GifImageFile.format, _save)
-PIL.Image.register_extension(GifImageFile.format, ".gif")
-PIL.Image.register_mime(GifImageFile.format, "image/gif")
-
-VERSION = "1.6"
+VERSION = "1.6.1"
 
 def scale(image, width, height):
     """
